RxControlInfo

Struct RxControlInfo 

pub struct RxControlInfo {
Show 20 fields pub rssi: i32, pub rate: u32, pub sig_len: u32, pub rx_state: u32, pub dump_len: u32, pub he_sigb_len: u32, pub cur_single_mpdu: u32, pub cur_bb_format: u32, pub rx_channel_estimate_info_vld: u32, pub rx_channel_estimate_len: u32, pub secondary_channel: SecondaryChannel, pub channel: u32, pub noise_floor: i32, pub is_group: u32, pub rxend_state: u32, pub rxmatch3: u32, pub rxmatch2: u32, pub rxmatch1: u32, pub rxmatch0: u32, pub timestamp: Instant,
}
Available on crate feature unstable only.
The radio metadata header of the received packet, which is the common header at the beginning of all RX callback buffers in promiscuous mode.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Fields

rssi: i32

Received Signal Strength Indicator (RSSI) of the packet, in dBm.

rate: u32

PHY rate encoding of the packet. Only valid for non-HT (802.11b/g) packets.

sig_len: u32

Length of the received packet including the Frame Check Sequence (FCS).

rx_state: u32

Reception state of the packet: 0 for no error, others indicate error codes.

dump_len: u32

Length of the dump buffer.

he_sigb_len: u32

Length of HE-SIG-B field (802.11ax).

cur_single_mpdu: u32

Indicates if this is a single MPDU.

cur_bb_format: u32

Current baseband format.

rx_channel_estimate_info_vld: u32

Channel estimation validity.

rx_channel_estimate_len: u32

Length of the channel estimation.

secondary_channel: SecondaryChannel

The secondary channel if in HT40. Otherwise invalid.

channel: u32

Primary channel on which the packet is received.

noise_floor: i32

Noise floor of the Radio Frequency module, in dBm.

is_group: u32

Indicates if this is a group-addressed frame.

rxend_state: u32

End state of the packet reception.

rxmatch3: u32

Indicate whether the reception frame is from interface 3.

rxmatch2: u32

Indicate whether the reception frame is from interface 2.

rxmatch1: u32

Indicate whether the reception frame is from interface 1.

rxmatch0: u32

Indicate whether the reception frame is from interface 0.

timestamp: Instant

The local time when this packet is received. It is precise only if modem sleep or light sleep is not enabled. unit: microsecond.